<?php
/**
 * MLBEvent is a concrete implementation of {@see MythEvent}. 
 *
 * @version $Id: MLBEvent.php,v 1.1.2.1 2006/11/05 23:06:57 dbattams Exp $
 * @author Derek Battams <derek@battams.ca>
 * @package MRE
 * @copyright 2006 GPL v2
 */

/**#@+
 * Required include
 */
require_once(APP_ROOT . '/class/MythEvent.php');
/**#@-*/

/**
 * MLBEvent monitors MLB games via ESPN.com 
 *
 * MLBEvent will monitor the status of MLB games via the information provided
 * by ESPN.com.
 *
 * @package MRE
 */
class MLBEvent extends MythEvent
{
   /**
    * URL to grab game info from
    */
   const url = 'http://scores.espn.go.com/mlb/scoreboard';

   /**
    * Class constructor.
    *
    * @param string A string describing the game to be monitored
    */
   public function __construct($gameInfo)
   {
      parent::__construct();

      $criteria = $this->generateSearchTerms($gameInfo);
      if(!sizeof($criteria))
         trigger_error("Unable to generate valid search terms! [$gameInfo]", E_USER_WARNING);
      else
      {
         $data = file(self::url);
         $games = array();
         if($data !== FALSE)
         {
            // Split the huge string into individual game data
            foreach($data as $line)
               if(preg_match('/\<div id="allGames".*\>.*/', $line))
               {
                  while(($loc = strrpos($line, 'teamTop')) !== FALSE)
                  {
                     $games[] = substr($line, $loc);
                     $line = substr($line, 0, $loc);
                  }
                  break;
               }
            if(!sizeof($games))
               trigger_error("Unable to find valid game data within source!", E_USER_WARNING);
            foreach($criteria as $term)
            {
               foreach($games as $game)
               {
                  if(preg_match('/' . preg_quote($term) . '/', $game))
                     if(preg_match('/teamTop.*\>(.*)\<\/td\>/U', $game, $matches))
                     {
                        $this->setStatus($matches[1]);
                        if(preg_match('/^(Final|Postponed)/', $matches[1]))
                           $this->setEventOver(TRUE);
                        else
                           $this->setEventOver(FALSE);
                        $this->setValid(TRUE);
                        break 2;
                     }
               }
            }
         }
      }
      if(!$this->isValid())
         trigger_error("Unable to find MLB info for '$gameInfo'!  The MLB parser may need to be updated.", E_USER_WARNING);
   }
}

?>
