<?php
/**
 * NBAEvent is a concrete implementation of {@see MythEvent}. 
 *
 * @version $Id: NBAEvent.php,v 1.9.2.1 2006/11/05 23:06:57 dbattams Exp $
 * @author Derek Battams <derek@battams.ca>
 * @package MRE
 * @copyright 2006 GPL v2
 */

/**#@+
 * Required include
 */
require_once(APP_ROOT . '/class/MythEvent.php');
/**#@-*/

/**
 * NBAEvent monitors NBA games via ESPN.com
 *
 * NBAEvent will monitor the status of NBA games via the information provided
 * by ESPN.com.
 *
 * @package MRE
 */
class NBAEvent extends MythEvent
{
   /**
    * URL to grab game info from
    */
   const url = 'http://scores.espn.go.com/nba/scoreboard';

   /**
    * Class constructor.
    *
    * @param string A string describing the game to be monitored
    */
   public function __construct($gameInfo)
   {
      parent::__construct();

      $criteria = $this->generateSearchTerms($gameInfo);
      if(!sizeof($criteria))
         trigger_error("Unable to generate valid search terms! [$gameInfo]", E_USER_WARNING);
      else
      {
         $data = file(self::url);
         if($data !== FALSE)
            foreach($criteria as $term)
            {
               $status = '';
               $i = 0;
               while($i < sizeof($data))
               {
                  if(preg_match('/' . preg_quote($term) . '/', $data[$i]))
                  {
                     $status = $data[$i];
                     break;
                  }
                  ++$i;
               }
               if($i == sizeof($data))
                  --$i;

               if(preg_match('/id.*clock"\>(.*)\<\/div/U', $data[$i], $match) ||
                  preg_match('/id.*clock"\>(.*)\<\/div/U', $data[$i-1], $match))
               {
                  $this->setStatus($match[1]);
                  if(preg_match('/^Final/', $match[1]))
                     $this->setEventOver(TRUE);
                  else
                     $this->setEventOver(FALSE);
                  $this->setValid(TRUE);
                  break;
               }
            }
      }
      if(!$this->isValid())
         trigger_error("Unable to find NBA info for '$gameInfo'!  The NBA parser may need to be updated.", E_USER_WARNING);
   }
}

?>
